qcacmn: [11AX] Add changes for 11ax peer association
Add changes for peer association by adding support to
include HE capabilities and HE operation information
in vdev start and peer assoc WMI commands.
Change-Id: I50c0241f872219e08ee2d231c907309ee5adceef
CRs-Fixed: 1073481
diff --git a/wmi_unified_param.h b/wmi_unified_param.h
index 840f610..728bde2 100644
--- a/wmi_unified_param.h
+++ b/wmi_unified_param.h
@@ -647,6 +647,7 @@
uint32_t preferred_tx_streams;
uint32_t cac_duration_ms;
uint32_t regdomain;
+ uint32_t he_ops;
#ifndef CONFIG_MCL
uint8_t oper_mode;
int32_t dfs_pri_multiplier;
@@ -975,14 +976,14 @@
#define WMI_HOST_MAX_NUM_SS 8
#define WMI_HOST_MAX_HECAP_PHY_SIZE 3
/**
* struct wmi_host_ppe_threshold -PPE threshold
* @numss_m1: NSS - 1
* @ru_count: Max RU count
* @ppet16_ppet8_ru3_ru0: ppet8 and ppet16 for max num ss
*/
struct wmi_host_ppe_threshold {
uint32_t numss_m1;
- uint32_t ru_count;
+ uint32_t ru_bit_mask;
uint32_t ppet16_ppet8_ru3_ru0[WMI_HOST_MAX_NUM_SS];
};
@@ -7074,7 +7075,7 @@
uint8_t *data;
};
-/*
+/**
* HW mode config type replicated from FW header
* @WMI_HOST_HW_MODE_SINGLE: Only one PHY is active.
* @WMI_HOST_HW_MODE_DBS: Both PHYs are active in different bands,
@@ -975,14 +976,14 @@
#define WMI_HOST_MAX_HECAP_PHY_SIZE 3
/**
- * struct wmi_host_ppe_threshold -PPE threshold
- * @numss_m1: NSS - 1
- * @ru_count: Max RU count
- * @ppet16_ppet8_ru3_ru0: ppet8 and ppet16 for max num ss
+ * struct wmi_host_ppe_threshold -PPE threshold
+ * @numss_m1: NSS - 1
+ * @ru_bit_mask: RU bit mask indicating the supported RU's
+ * @ppet16_ppet8_ru3_ru0: ppet8 and ppet16 for max num ss
*/
struct wmi_host_ppe_threshold {